@@ -250,7 +250,7 @@ sub get_str {
     my $good = $this->[0];
     my $bad  = $this->[1];
 
-    my $str = "if ( \$PRIV(bvalflag) ) { PDL_COMMENT(\"** do 'bad' Code **\")\n";
+    my $str = PDL::PP::pp_line_numbers(__LINE__, "if ( \$PRIV(bvalflag) ) { PDL_COMMENT(\"** do 'bad' Code **\")\n");
     $str .= "\n#define PDL_BAD_CODE\n";
     $str .= $bad->get_str($parent,$context);
     $str .= "\n#undef PDL_BAD_CODE\n";
@@ -290,7 +290,7 @@ sub myprelude { my($this,$parent,$context) = @_;
 			for($_=0; $_<(__$i->[0]_size); $_++) {";
 		$i;
 	} @{$this->[0]};
-	return $text;
+	return PDL::PP::pp_line_numbers(__LINE__, $text);
 }
 sub mypostlude { my($this,$parent,$context) = @_;
 	splice @$context, - ($#{$this->[0]}+1);
@@ -373,12 +373,12 @@ sub myitem {
 				"#define THISIS$this->[1]_$item->[3](a) a\n";
     }
 
-    return "\t} break; case $item->[0]: {\n".
+    return PDL::PP::pp_line_numbers(__LINE__, "\t} break; case $item->[0]: {\n".
 	$thisis_loop .
 	    (join '',map{
 		# print "DAPAT: '$_'\n";
 		$parent->{ParObjs}{$_}->get_xsdatapdecl($item->[1]);
-	    } (@{$this->[2]})) ;
+	    } (@{$this->[2]})));
 }
 
 sub mypostlude {
@@ -413,13 +413,13 @@ sub myoffs { return 0; }
 sub myprelude {my($this,$parent,$context) = @_;
  my $no;
  my ($ord,$pdls) = $parent->get_pdls();
-'	PDL_COMMENT("THREADLOOPBEGIN")
+PDL::PP::pp_line_numbers(__LINE__, '	PDL_COMMENT("THREADLOOPBEGIN")
  if(PDL->startthreadloop(&($PRIV(__pdlthread)),$PRIV(vtable)->readdata,
  	__privtrans))) return;
    do {
  '.(join '',map {"${_}_datap += \$PRIV(__pdlthread).offs[".(0+$no++)."];\n"}
  		@$ord).'
-';
+');
 }
 
 sub mypostlude {my($this,$parent,$context) = @_;
@@ -459,45 +459,56 @@ sub myprelude {
 
     my ($ord,$pdls) = $parent->get_pdls();
 
-    join( "\n	",
-	  '',
-	  'PDL_COMMENT("THREADLOOPBEGIN")',
-	  'if ( PDL->startthreadloop(&($PRIV(__pdlthread)),$PRIV(vtable)->'.$funcName.', __tr) ) return;
-           do { register PDL_Indx __tind1=0,__tind2=0;
-                register PDL_Indx __tnpdls = $PRIV(__pdlthread).npdls;
-                register PDL_Indx __tdims1 = $PRIV(__pdlthread.dims[1]);
-                register PDL_Indx __tdims0 = $PRIV(__pdlthread.dims[0]);
-                register PDL_Indx *__offsp = PDL->get_threadoffsp(&$PRIV(__pdlthread));',
+    my $str = '';
+    my $loop_key = "emitted_startthreadloop_$funcName";
+    my $macro_name = "PDL_STARTTHREADLOOP_$parent->{Name}_$funcName";
+    if (!$parent->{$loop_key}) {
+	$parent->{$loop_key} = 1;
+	$str .= join " \\\n\t",
+	  "#define $macro_name",
+	  'if ( PDL->startthreadloop(&($PRIV(__pdlthread)),$PRIV(vtable)->'.$funcName.', __tr) ) return; \
+	   do { register PDL_Indx __tind1=0,__tind2=0; \
+		register PDL_Indx __tnpdls = $PRIV(__pdlthread).npdls; \
+		register PDL_Indx __tdims1 = $PRIV(__pdlthread.dims[1]); \
+		register PDL_Indx __tdims0 = $PRIV(__pdlthread.dims[0]); \
+		register PDL_Indx *__offsp = PDL->get_threadoffsp(&$PRIV(__pdlthread));',
 	  ( map { "register PDL_Indx __tinc0_${_} = \$PRIV(__pdlthread).incs[${_}];"} 0..$#{$ord}),
 	  ( map { "register PDL_Indx __tinc1_${_} = \$PRIV(__pdlthread).incs[__tnpdls+$_];"} 0.. $#{$ord}),
 	  ( map { $ord->[$_] ."_datap += __offsp[$_];"} 0..$#{$ord} ),
-	  'for( __tind2 = 0 ;
-                __tind2 < __tdims1 ;
-                __tind2++',
-	        ( map { "\t\t," . $ord->[$_] . "_datap += __tinc1_${_} - __tinc0_${_} * __tdims0"} 0..$#{$ord} ),
-             ')',
-	  '{
-	     for( __tind1 = 0 ;
-                  __tind1 < __tdims0 ;
-                  __tind1++',
-	          ( map { "\t\t," . $ord->[$_] . "_datap += __tinc0_${_}"} 0..$#{$ord}),
-	       ')',
-           '{  PDL_COMMENT("This is the tightest threadloop. Make sure inside is optimal.")'
-	);
+	  'for( __tind2 = 0 ; \
+		__tind2 < __tdims1 ; \
+		__tind2++',
+		( map { "\t\t," . $ord->[$_] . "_datap += __tinc1_${_} - __tinc0_${_} * __tdims0"} 0..$#{$ord} ),
+	     ')',
+	  '{ \
+	     for( __tind1 = 0 ; \
+		  __tind1 < __tdims0 ; \
+		  __tind1++',
+		  ( map { "\t\t," . $ord->[$_] . "_datap += __tinc0_${_}"} 0..$#{$ord}),
+	       ") {",
+	  "PDL_COMMENT(\"This is the tightest threadloop. Make sure inside is optimal.\")\n\n",
+	;
+    }
+    $str . PDL::PP::pp_line_numbers(__LINE__, $macro_name);
 }
 
 # Should possibly fold out thread.dims[0] and [1].
 sub mypostlude {my($this,$parent,$context) = @_;
-
- my ($ord,$pdls) = $parent->get_pdls();
- join( "\n	",
-       '',
-       'PDL_COMMENT("THREADLOOPEND")',
-       '}',
-       '}',
-       ( map { $ord->[$_] . "_datap -= __tinc1_${_} * __tdims1 + __offsp[${_}];"} 0..$#{$ord} ),
-       '} while(PDL->iterthreadloop(&$PRIV(__pdlthread),2));'
-     )
+    my ($ord,$pdls) = $parent->get_pdls();
+    my $loop_key = "emitted_endthreadloop";
+    my $macro_name = "PDL_ENDTHREADLOOP_$parent->{Name}";
+    my $str = '';
+    if (!$parent->{$loop_key}) {
+	$parent->{$loop_key} = 1;
+	$str .= join " \\\n\t",
+	    "\n#define $macro_name",
+	    '}',
+	    '}',
+	    ( map { $ord->[$_] . "_datap -= __tinc1_${_} * __tdims1 + __offsp[${_}];"} 0..$#{$ord} ),
+	    '} while(PDL->iterthreadloop(&$PRIV(__pdlthread),2));'."\n",
+	    ;
+    }
+    $str . PDL::PP::pp_line_numbers(__LINE__, $macro_name);
 }
 
 # Simple subclass of ComplexThreadLoop to implement writeback code
@@ -631,6 +642,8 @@ my %set_nan =
     (
      float  => 'PDL->bvals.Float',  PDL_Float  => 'PDL->bvals.Float',
      double => 'PDL->bvals.Double', PDL_Double => 'PDL->bvals.Double',
+     cfloat => 'PDL->bvals.CFloat', PDL_CFloat => 'PDL->bvals.CFloat',
+     cdouble => 'PDL->bvals.CDouble', PDL_CDouble => 'PDL->bvals.CDouble',
      );
 
 sub use_nan ($) {
